==> jc-1.4.0.tar.gz: java/security/KeyPair.h <==
// public final class java.security.KeyPair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 60b9183ffe1284b3 java_security_KeyPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_KeyPair_H_
#define _JC_java_security_KeyPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_PublicKey$object;

// Typedefs
typedef struct _jc_java_security_KeyPair$sub_refs	_jc_java_security_KeyPair$sub_refs;
typedef struct _jc_java_security_KeyPair$sub_nonrefs	_jc_java_security_KeyPair$sub_nonrefs;
typedef struct _jc_java_security_KeyPair$refs	_jc_java_security_KeyPair$refs;
typedef struct _jc_java_security_KeyPair$nonrefs	_jc_java_security_KeyPair$nonrefs;
typedef struct _jc_java_security_KeyPair$object	_jc_java_security_KeyPair$object;

typedef struct _jc_java_security_KeyPair$fields_struct	_jc_java_security_KeyPair$fields_struct;
typedef const struct _jc_java_security_KeyPair$vmethods	_jc_java_security_KeyPair$vmethods;
typedef const struct _jc_java_security_KeyPair$vtable	_jc_java_security_KeyPair$vtable;
typedef const struct _jc_java_security_KeyPair$vtype	_jc_java_security_KeyPair$vtype;

// Class fields structure
struct _jc_java_security_KeyPair$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_KeyPair$fields_struct _jc_java_security_KeyPair$class_fields;

// Constructors
extern void _jc_java_security_KeyPair$method$_init$80245b525558cb82(_jc_env *, struct _jc_java_security_KeyPair$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_security_KeyPair$method$getPrivate$746d3375b5a2b8a4(_jc_env *, struct _jc_java_security_KeyPair$object *);
extern struct _jc_object *_jc_java_security_KeyPair$method$getPublic$d242320b62c062e6(_jc_env *, struct _jc_java_security_KeyPair$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_KeyPair$method_info$getPrivate$746d3375b5a2b8a4;
extern _jc_method _jc_java_security_KeyPair$method_info$getPublic$d242320b62c062e6;

// Virtual methods structure
struct _jc_java_security_KeyPair$vmethods {
	struct _jc_object	*(*getPrivate$746d3375b5a2b8a4)(_jc_env *, struct _jc_java_security_KeyPair$object *);
	struct _jc_object	*(*getPublic$d242320b62c062e6)(_jc_env *, struct _jc_java_security_KeyPair$object *);
};

// Vtable
struct _jc_java_security_KeyPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyPair$vmethods	java_security_KeyPair;
};

// Vtype
struct _jc_java_security_KeyPair$vtype {
	_jc_type			type;
	_jc_java_security_KeyPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_KeyPair$sub_refs {
	struct _jc_object	*publicKey;
	struct _jc_object	*privateKey;
};

// Reference instance fields (object)
struct _jc_java_security_KeyPair$refs {
    _jc_java_security_KeyPair$sub_refs	java_security_KeyPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_KeyPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_KeyPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyPair$sub_nonrefs	java_security_KeyPair;
};

// Object instance structure
struct _jc_java_security_KeyPair$object {
	_jc_java_security_KeyPair$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_KeyPair$vtype	*vtype;
	_jc_java_security_KeyPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_KeyPair$vtype _jc_java_security_KeyPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_KeyPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_KeyPair$class_object;

#endif	/* _JC_java_security_KeyPair_H_ */

==> jc-1.4.6.tar.gz: java/security/KeyPair.h <==
// public final class java.security.KeyPair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 60b9183ffe1284b3 java_security_KeyPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_KeyPair_H_
#define _JC_java_security_KeyPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_PrivateKey$object;
struct _jc_java_security_PublicKey$object;

// Typedefs
typedef struct _jc_java_security_KeyPair$sub_refs	_jc_java_security_KeyPair$sub_refs;
typedef struct _jc_java_security_KeyPair$sub_nonrefs	_jc_java_security_KeyPair$sub_nonrefs;
typedef struct _jc_java_security_KeyPair$refs	_jc_java_security_KeyPair$refs;
typedef struct _jc_java_security_KeyPair$nonrefs	_jc_java_security_KeyPair$nonrefs;
typedef struct _jc_java_security_KeyPair$object	_jc_java_security_KeyPair$object;

typedef struct _jc_java_security_KeyPair$fields_struct	_jc_java_security_KeyPair$fields_struct;
typedef const struct _jc_java_security_KeyPair$vmethods	_jc_java_security_KeyPair$vmethods;
typedef const struct _jc_java_security_KeyPair$vtable	_jc_java_security_KeyPair$vtable;
typedef const struct _jc_java_security_KeyPair$vtype	_jc_java_security_KeyPair$vtype;

// Class fields structure
struct _jc_java_security_KeyPair$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_KeyPair$fields_struct _jc_java_security_KeyPair$class_fields;

// Constructors
extern void _jc_java_security_KeyPair$method$_init$80245b525558cb82(_jc_env *, struct _jc_java_security_KeyPair$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_security_KeyPair$method$getPrivate$746d3375b5a2b8a4(_jc_env *, struct _jc_java_security_KeyPair$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_KeyPair$method$getPublic$d242320b62c062e6(_jc_env *, struct _jc_java_security_KeyPair$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_KeyPair$method_info$getPrivate$746d3375b5a2b8a4;
extern _jc_method _jc_java_security_KeyPair$method_info$getPublic$d242320b62c062e6;

// Virtual methods structure
struct _jc_java_security_KeyPair$vmethods {
	struct _jc_object	*(*getPrivate$746d3375b5a2b8a4)(_jc_env *, struct _jc_java_security_KeyPair$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPublic$d242320b62c062e6)(_jc_env *, struct _jc_java_security_KeyPair$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_KeyPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_KeyPair$vmethods	java_security_KeyPair;
};

// Vtype
struct _jc_java_security_KeyPair$vtype {
	_jc_type			type;
	_jc_java_security_KeyPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_KeyPair$sub_refs {
	struct _jc_object	*publicKey;
	struct _jc_object	*privateKey;
};

// Reference instance fields (object)
struct _jc_java_security_KeyPair$refs {
    _jc_java_security_KeyPair$sub_refs	java_security_KeyPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_KeyPair$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_KeyPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_KeyPair$sub_nonrefs	java_security_KeyPair;
};

// Object instance structure
struct _jc_java_security_KeyPair$object {
	_jc_java_security_KeyPair$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_KeyPair$vtype	*vtype;
	_jc_java_security_KeyPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_KeyPair$vtype _jc_java_security_KeyPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_KeyPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_KeyPair$class_object;

#endif	/* _JC_java_security_KeyPair_H_ */
